<?php
namespace Modules\Cadastros\Controllers;

use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\Report\ReportService;


class Cmp02500DadosDeProdutosNaUnidade extends \Zeedhi\Framework\Controller\Report {
    
    protected $connection;
    protected $qr2Strategy;
    protected $stNomeRel;
    protected $stExtensao;
    
    public function __construct(ReportService $reportService, $connection, $qr2Strategy, $environment) {
        parent::__construct($reportService);
        $this->connection    = $connection;
        $this->qr2Strategy   = $qr2Strategy;
        $this->environment   = $environment;
    }
    
    
    public function executaSql($sql, $params, $consulta = true) {
        try{
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
            if($consulta == true) {
                return $std->fetchAll();
            }
            
            return true;
        } catch (\Exception $e){
            throw $e;
        } 
    }
    
    
    public function verificaCampos(DTO\Request $request, DTO\Response $response) {
        
        $params = array(
            "NRORG" => $this->environment->getNrorg()
        );
        
        $sql   = "SELECT IDSISDOS FROM PARAMGERAL WHERE NRORG = :NRORG";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        $valor = $query->fetchAll();
        $response->addDataSet(new DataSet("resp", $valor));
        
    }
    
    
    function verificaExisteProdutoPai($cdfilial, $cdarvprod, $tipo) {
        
        if($tipo === 'COMPRADO') {
            
            $sql = "SELECT PRODCMPFILI.CDPRODUTO FROM PRODCMPFILI, PRODUTO WHERE( PRODCMPFILI.CDFILIAL =:CDFILIAL) AND ( PRODCMPFILI.NRORG = :NRORG ) AND ( PRODCMPFILI.CDPRODUTO = PRODUTO.CDPRODUTO ) AND ( PRODCMPFILI.NRORG = PRODUTO.NRORG ) AND ( :CDARVPROD LIKE CDARVPROD || '%' )";
            
        } else {
            
            $sql = "SELECT PRODNCMP.CDPRODUTO FROM PRODNCMP, PRODUTO WHERE( PRODNCMP.CDFILIAL =:CDFILIAL) AND ( PRODNCMP.NRORG = :NRORG ) AND ( PRODNCMP.CDPRODUTO = PRODUTO.CDPRODUTO ) AND ( PRODNCMP.NRORG = PRODUTO.NRORG ) AND ( :CDARVPROD LIKE CDARVPROD || '%' )";
            
        }
        
        $params = [
            "CDFILIAL" => $cdfilial,
            "CDARVPROD" => $cdarvprod,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];
        
        $produtoPai = self::executaSql($sql, $params);
        
        if (is_array($produtoPai) && count($produtoPai)) {
            throw new \Exception('Grupo do produto já cadastrado.');
        }
    }
    
    function verificaExisteProdutoFilho($cdfilial, $cdarvprod, $tipo) {
        
        if($tipo === 'COMPRADO') {
            
            $sql = "SELECT PRODCMPFILI.CDPRODUTO FROM PRODCMPFILI, PRODUTO WHERE( PRODCMPFILI.CDFILIAL =:CDFILIAL) AND ( PRODCMPFILI.NRORG = :NRORG ) AND ( PRODCMPFILI.CDPRODUTO = PRODUTO.CDPRODUTO ) AND ( PRODCMPFILI.NRORG = PRODUTO.NRORG ) AND ( CDARVPROD LIKE :CDARVPROD || '%' )";
            
        } else {
            
            $sql = "SELECT PRODNCMP.CDPRODUTO FROM PRODNCMP, PRODUTO WHERE( PRODNCMP.CDFILIAL =:CDFILIAL) AND ( PRODNCMP.NRORG = :NRORG ) AND ( PRODNCMP.CDPRODUTO = PRODUTO.CDPRODUTO ) AND ( PRODNCMP.NRORG = PRODUTO.NRORG ) AND ( CDARVPROD LIKE :CDARVPROD || '%' )";
            
        }
        
        $params = [
            "CDFILIAL" => $cdfilial,
            "CDARVPROD" => $cdarvprod,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];
        
        $produtoFilho = self::executaSql($sql, $params);

        return count($produtoFilho) ? true : false;
        
    }
    
    
    function verificaExisteProduto($cdfilial, $cdarvprod, $tipo, $mensagemErro) {
        
        if($tipo === 'COMPRADO') {
            
            $sql = "SELECT PRODCMPFILI.CDPRODUTO FROM PRODCMPFILI, PRODUTO WHERE( PRODCMPFILI.CDFILIAL =:CDFILIAL) AND ( PRODCMPFILI.NRORG = :NRORG ) AND ( PRODCMPFILI.CDPRODUTO = PRODUTO.CDPRODUTO ) AND ( PRODCMPFILI.NRORG = PRODUTO.NRORG ) AND ( CDARVPROD = :CDARVPROD)";
            
        } else {
            
            $sql = "SELECT PRODNCMP.CDPRODUTO FROM PRODNCMP, PRODUTO WHERE( PRODNCMP.CDFILIAL =:CDFILIAL) AND ( PRODNCMP.NRORG = :NRORG ) AND ( PRODNCMP.CDPRODUTO = PRODUTO.CDPRODUTO ) AND ( PRODNCMP.NRORG = PRODUTO.NRORG ) AND ( CDARVPROD = :CDARVPROD)";
            
        }
        
        $params = [
            "CDFILIAL" => $cdfilial,
            "CDARVPROD" => $cdarvprod,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];
        
        $produto = self::executaSql($sql, $params);
        
        if (is_array($produto) && count($produto)) {
            throw new \Exception($mensagemErro);
        }
    }
    
    public function insereProduto($cdfilial, $cdproduto, $tipo) {
        
        if('COMPRADO') {
            
            $sql = "INSERT INTO PRODCMPFILI (CDFILIAL, CDPRODUTO, DTULTATUPCMP, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRORG) VALUES (:CDFILIAL, :CDPRODUTO, SYSDATE, SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORG)";
            
        } else {
            
            $sql = "INSERT INTO PRODNCMP (CDFILIAL, CDPRODUTO, DTULTATUPCMP, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, NRORG) VALUES (:CDFILIAL, :CDPRODUTO, SYSDATE, SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORG)";
            
        }
        
        $params = [
            "CDFILIAL" => $cdfilial,
            "CDPRODUTO" => $cdproduto,
            "NRORGINCLUSAO" => $this->environment->getNrOrgTrab(),
            "CDOPERINCLUSAO" => $this->environment->getCdoperador(),
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        self::executaSql($sql, $params, false);

    }
    
    
    //PRODUTO COMPRADO
    
    public function salvarProdutoComprado(DTO\Request\Row $request, DTO\Response $response) {
        
        $row = $request->getRow();
        
        $cdfilial = $row['CDFILIAL'];
        $cdarvprod = $row['CDARVPROD'];
        $cdproduto = $row['CDPRODUTO'];
        
        try {
            self::verificaExisteProduto($cdfilial, $cdarvprod, 'COMPRADO', 'Produto já cadastrado.');
            
            self::verificaExisteProduto($cdfilial, $cdarvprod, 'NAO_COMPRADO', 'Produto já cadastrado para não ser comprado nesta unidade.');
            
            self::verificaExisteProdutoPai($cdfilial, $cdarvprod, 'COMPRADO');
            
            $produtoFilho = self::verificaExisteProdutoFilho($cdfilial, $cdarvprod, 'COMPRADO');
            if(!$produtoFilho) {
                
                self::insereProduto($cdfilial, $cdproduto, 'COMPRADO');
                $response->addMessage(new Message(true));
                
            } else {
                
                $response->addMessage(new Message('EXIBIR_CONFIRMACAO'));
                
            }
            
        } catch(\Exception $e) {
            
            $response->setError(new Error($e->getMessage(), 1));
            
        }
        
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    // public function saveProdutoComprado(DTO\Request $request, DTO\Response $response)
    // {
    //     $data = $request->getDataSet()->getRows();
    //     $selectProduto = "SELECT PRODCMPFILI.CDFILIAL, PRODCMPFILI.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO FROM PRODCMPFILI, PRODUTO WHERE (PRODCMPFILI.CDFILIAL = :P_CDFILIAL) AND (PRODCMPFILI.CDPRODUTO = PRODUTO.CDPRODUTO) AND (CDARVPROD LIKE :P_CDARVPROD||'%') AND (CDARVPROD >= :P_CDARVPROD) ORDER BY PRODUTO.CDARVPROD";
        
    //     $params                = array();
    //     $params['P_CDFILIAL']  = $data[0]['CDFILIAL'];
    //     $params['P_CDARVPROD'] = $data[0]['CDARVPROD'];
        
        
    //     $stmt = $this->connection->prepare($selectProduto);
    //     $stmt->execute($params);
    //     $retorno = $stmt->fetchAll();
    //     $response->addDataSet(new DataSet("resp", $retorno));
        
        
    // }
 
//     public function verificaProdutoNaoComprado(DTO\Request $request, DTO\Response $response) {
//         $data = $request->getDataSet()->getRows();
//         $selectProduto = "SELECT CDFILIAL, CDPRODUTO,NRORG FROM PRODNCMP WHERE CDFILIAL = :P_CDFILIAL AND CDPRODUTO = :P_CDPRODUTO AND NRORG = :NRORG";
        
//         $params                = array();
//         $params['P_CDFILIAL']  = $data[0]['CDFILIAL'];
//         $params['P_CDPRODUTO'] = $data[0]['CDPRODUTO'];
//         $params['NRORG']     = $this->environment->getNrorg();
        
        
//         $stmt = $this->connection->prepare($selectProduto);
//         $stmt->execute($params);
//         $retornoVerificacao = $stmt->fetchAll();
//         $response->addDataSet(new DataSet("response", $retornoVerificacao));
//     }
    
//  public function verificaProdutoComprado(DTO\Request $request, DTO\Response $response) {
//         $data = $request->getDataSet()->getRows();
//         $selectProduto = "SELECT CDFILIAL, CDPRODUTO,NRORG FROM PRODCMPFILI WHERE CDFILIAL = :P_CDFILIAL AND CDPRODUTO = :P_CDPRODUTO AND NRORG = :NRORG";
        
//         $params                = array();
//         $params['P_CDFILIAL']  = $data[0]['CDFILIAL'];
//         $params['P_CDPRODUTO'] = $data[0]['CDPRODUTO'];
//         $params['NRORG']     = $this->environment->getNrorg();
        
        
//         $stmt = $this->connection->prepare($selectProduto);
//         $stmt->execute($params);
//         $retornoVerificacao = $stmt->fetchAll();
//         $response->addDataSet(new DataSet("response", $retornoVerificacao));
//     }
    
    
    
    public function deleteNivelProdutoComprado(DTO\Request $request, DTO\Response $response) {
        
       $data = $request->getDataSet()->getRows();
        
        $query = 'DELETE FROM PRODCMPFILI WHERE (CDFILIAL = :P_CDFILIAL) AND (INSTR((SELECT PRODUTO.CDARVPROD FROM PRODUTO WHERE PRODUTO.CDPRODUTO = PRODCMPFILI.CDPRODUTO), :P_CDPRODUTO) = 1) AND ((SELECT P.CDARVPROD FROM PRODUTO P WHERE P.CDPRODUTO = PRODCMPFILI.CDPRODUTO) >= :P_CDPRODUTO)';
        $stmt  = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILIAL" => $data[0]['CDFILIAL'],
            "P_CDPRODUTO" => $data[0]['CDPRODUTO']
        ));
    }
    public function deleteProdutoComprado(DTO\Request $request, DTO\Response $response)
    {
        
       $data = $request->getRow();
        $query = 'delete from PRODCMPFILI where CDFILIAL = :P_CDFILIAL and CDPRODUTO = :P_CDPRODUTO';
        $stmt  = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILIAL" => $data['CDFILIAL'],
            "P_CDPRODUTO" => $data['CDPRODUTO']
        ));
    }
    
    
    //aba Produto Nao Comprado
    public function saveProdutoNaoComprado(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $selectProdutoComprado = "SELECT PRODCMPFILI.CDFILIAL, PRODCMPFILI.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PRODUTO.NRORG FROM PRODCMPFILI, PRODUTO WHERE (PRODCMPFILI.CDFILIAL = :CDFILIAL) AND (PRODCMPFILI.CDPRODUTO = PRODUTO.CDPRODUTO) AND (PRODUTO.CDPRODUTO = :CDPRODUTO) ORDER BY PRODUTO.CDARVPROD";
        $stmt = $this->connection->prepare($selectProdutoComprado);
        $params = array(
            "CDPRODUTO" => $row["CDPRODUTO"],
            "CDFILIAL" => $row["CDFILIAL"]
        );
        $stmt->execute($params);
        $result = $stmt->fetchAll();
        if(empty($result)){
            try {
                self::verificaExisteProdutoPai($row['CDFILIAL'], $row['CDARVPROD'], 'NAO_COMPRADO');
                $produtoFilho = self::verificaExisteProdutoFilho($row['CDFILIAL'], $row['CDARVPROD'], 'NAO_COMPRADO');
                if(!$produtoFilho) {
                    $this->insereProdutoNaoComprado($request, $response);
                    $response->addMessage(new Message(true));
                } else {
                    $response->addMessage(new Message('EXIBIR_CONFIRMACAO'));
                }
            } catch (\Exception $e) {
                $response->setError(new Error($e->getMessage(),500));
            }
        } else {
            $response->setError(new Error('Produto já cadastrado para ser comprado nesta unidade!', 500));
        }
    }
        
    public function insereProdutoNaoComprado(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $params              = array();
        $params['CDFILIAL']  = $row['CDFILIAL'];
        $params['CDPRODUTO'] = $row['CDPRODUTO'];
        $params['NRORG']     = $this->environment->getNrorg();
        $sql = "INSERT INTO PRODNCMP (CDFILIAL, CDPRODUTO, NRORG) VALUES (:CDFILIAL, :CDPRODUTO, :NRORG)";
        $std = $this->connection->prepare($sql);
        $this->connection->beginTransaction();
        try {
            $std->execute($params);
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
        
    }
      
    public function deleteNivelProdutoNaoComprado(DTO\Request $request, DTO\Response $response)
     {
        
        $row = $request->getRow();
        
        $query = 'DELETE FROM PRODNCMP WHERE (CDFILIAL = :P_CDFILIAL) AND (INSTR((SELECT PRODUTO.CDARVPROD FROM PRODUTO WHERE PRODUTO.CDPRODUTO = PRODNCMP.CDPRODUTO), :P_CDPRODUTO) = 1) AND ((SELECT P.CDARVPROD FROM PRODUTO P WHERE P.CDPRODUTO = PRODNCMP.CDPRODUTO) >= :P_CDPRODUTO)';
        $stmt  = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILIAL" => $row['CDFILIAL'],
            "P_CDPRODUTO" => $row['CDPRODUTO']
        ));
    }
    
    public function deleteProdutoNaoComprado(DTO\Request $request, DTO\Response $response)
     {
        
        $data = $request->getRow();
        
        $query = 'delete from ProdnCmp where CDPRODUTO = :P_CDPRODUTO and CDFILIAL = :P_CDFILIAL';
        $stmt  = $this->connection->prepare($query);
        $stmt->execute(array(
            "P_CDFILIAL" => $data['CDFILIAL'],
            "P_CDPRODUTO" => $data['CDPRODUTO']
        ));
    }
    
    //aba Periodicidade da Entrega 
    public function recordFoundPerientr(DTO\Request $request, DTO\Response $response){
        
        $row = $request->getRow();
        
        $selectPerientr = "SELECT 
                                CDFILIAL, 
                                CDPRODUTO, 
                                CDPERIENTR
                            FROM PERFILPROD
                           WHERE CDFILIAL = :CDFILIAL
                                AND CDPRODUTO  = :CDPRODUTO
                                AND NRORG      = :NRORG";
        
        $params = array();
        
        $params['CDFILIAL']   = $row['CDFILIAL'];
        $params['CDPRODUTO']  = $row['CDPRODUTO'];
        $params['NRORG']      = $this->environment->getNrorg(); 
        
        
        $stmt    = $this->connection->prepare($selectPerientr);
        $stmt->execute($params);
        $retorno = $stmt->fetchAll();
        $response->addDataSet(new DataSet("callback", $retorno));
    }
    public function inserePeriodicidade(DTO\Request $request, DTO\Response $response)
    {
         
         $data = $request->getDataSet()->getRows();
         $params              = array();
                $params['CDFILIAL']  = $data[0]['CDFILIAL'];
                $params['CDPRODUTO'] = $data[0]['CDPRODUTO'];
                $params['CDPERIENTR'] = $data[0]['CDPERIENTR'];
                $params['NRORG']     = $this->environment->getNrorg();
                
        
        $sql = "INSERT INTO PERFILPROD (CDFILIAL, CDPRODUTO, CDPERIENTR, NRORG) VALUES (:CDFILIAL, :CDPRODUTO, :CDPERIENTR, :NRORG)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
                
        
    }
     public function editaPeriodicidade(DTO\Request $request, DTO\Response $response)
    {
        
         $data = $request->getDataSet()->getRows();
         $params              = array();
                $params['CDPERIENTR']  = $data[0]['CDPERIENTR'];
                $params['IDDNULIMSEGPR'] = $data[0]['IDDNULIMSEGPR'];
                $params['IDSITUENTREGA'] = $data[0]['IDSITUENTREGA'];
                $params['OLD_CDFILIAL'] = $data[0]['CDFILIAL'];
                $params['OLD_CDPRODUTO'] = $data[0]['CDPRODUTO'];
                $params['NRORG']     = $this->environment->getNrorg();

        $sql = "UPDATE PERFILPROD SET CDPERIENTR = :CDPERIENTR, IDDNULIMSEGPR = :IDDNULIMSEGPR, IDSITUENTREGA = :IDSITUENTREGA WHERE CDFILIAL = :OLD_CDFILIAL AND CDPRODUTO = :OLD_CDPRODUTO AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        
        
    }
    public function deletePeriodicidade(DTO\Request $request, DTO\Response $response)
     {
        
        $data = $request->getRow();
         
        $query = 'DELETE FROM PERFILPROD WHERE CDFILIAL = :OLD_CDFILIAL AND CDPRODUTO = :OLD_CDPRODUTO AND NRORG = :NRORG';
        $stmt  = $this->connection->prepare($query);
        $stmt->execute(array(
            "OLD_CDFILIAL" => $data['CDFILIAL'],
            "OLD_CDPRODUTO" => $data['CDPRODUTO'],
            "NRORG" =>  $this->environment->getNrorg()
        ));
    }
      public function salvaLimiteSeguranca(DTO\Request $request, DTO\Response $response)
    {
        
         $data = $request->getDataSet()->getRows();
         $params              = array();
                $params['CDPERIENTR']  = $data[0]['CDPERIENTR'];
                $params['IDDNULIMSEGPR'] = $data[0]['IDDNULIMSEGPR'];
                $params['IDSITUENTREGA'] = $data[0]['IDSITUENTREGA'];
                $params['OLD_CDFILIAL'] = $data[0]['CDFILIAL'];
                $params['OLD_CDPRODUTO'] = $data[0]['CDPRODUTO'];
                $params['NRORG']     = $this->environment->getNrorg();
                
        
        $sql = "UPDATE PERFILPROD SET CDPERIENTR = :CDPERIENTR, IDDNULIMSEGPR = :IDDNULIMSEGPR, IDSITUENTREGA = :IDSITUENTREGA WHERE CDFILIAL = :OLD_CDFILIAL AND CDPRODUTO = :OLD_CDPRODUTO AND CDPERIENTR = :CDPERIENTR AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    //aba Destinatário NF
    
     public function recordFoundDest(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        $params              = array();
        $params['CDFILIAL']  = $row['CDFILIAL'];
        $params['CDPRODUTO'] = $row['CDPRODUTO'];
        $params['NRORG']     = $this->environment->getNrorg();
                
        
        $sql = "SELECT CDFILIAL,
                       CDPRODUTO,
                       IDEMITAFDES,
                       CDEMPRESA,
                       NRORG
                  FROM EMITENTEAF 
                  WHERE
                    CDFILIAL = :CDFILIAL AND
                    CDPRODUTO = :CDPRODUTO AND
                    NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $response->addDataSet(new DataSet("callback", $std->fetchAll()));
    }
     public function insereDestinatario(DTO\Request $request, DTO\Response $response)
    {
         $data = $request->getDataSet()->getRows();
         $params              = array();
                $params['CDFILIAL']  = $data[0]['CDFILIAL'];
                $params['CDPRODUTO'] = $data[0]['CDPRODUTO'];
                $params['IDEMITAFDES'] = $data[0]['IDEMITAFDES'];
                $params['CDEMPRESA'] = $data[0]['CDEMPRESA'];
                $params['NRORG']     = $this->environment->getNrorg();
                
        
        $sql = "INSERT INTO EMITENTEAF (CDFILIAL, CDPRODUTO, IDEMITAFDES, CDEMPRESA, NRORG) VALUES (:CDFILIAL, :CDPRODUTO, :IDEMITAFDES, :CDEMPRESA, :NRORG)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
                
        
    }
     public function editaDestinatario(DTO\Request $request, DTO\Response $response)
    {

         $data = $request->getDataSet()->getRows();
            
        $params = array();
        
        $params['CDFILIAL']      = $data[0]['CDFILIAL'];
        $params['CDPRODUTO']     = $data[0]['CDPRODUTO'];
        $params['IDEMITAFDES']   = $data[0]['IDEMITAFDES'];
        $params['CDEMPRESA']     = $data[0]['CDEMPRESA'];
        $params['OLD_CDFILIAL']  = $data[0]['CDFILIAL'];
        $params['OLD_CDPRODUTO'] = $data[0]['CDPRODUTO'];
        $params['NRORG']         = $this->environment->getNrorg();
        
        $sql = "UPDATE EMITENTEAF SET CDFILIAL = :CDFILIAL, CDPRODUTO = :CDPRODUTO, IDEMITAFDES = :IDEMITAFDES, CDEMPRESA = :CDEMPRESA WHERE CDFILIAL = :OLD_CDFILIAL AND CDPRODUTO = :OLD_CDPRODUTO AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
                
        
    }
    public function deleteDestinatario(DTO\Request $request, DTO\Response $response)
     {
        
        $data = $request->getRow();
        
        $query = 'DELETE FROM EMITENTEAF WHERE CDFILIAL = :OLD_CDFILIAL AND CDPRODUTO = :OLD_CDPRODUTO AND NRORG = :NRORG';
        $stmt  = $this->connection->prepare($query);
        $stmt->execute(array(
            "OLD_CDFILIAL" => $data['CDFILIAL'],
            "OLD_CDPRODUTO" => $data['CDPRODUTO'],
            "NRORG" =>  $this->environment->getNrorg()
        ));
    }
    //aba Limite de Seguranca
    
    public function verificaLimSeguranca(DTO\Request $request, DTO\Response $response){
        
        $data = $request->getDataSet()->getRows();
        
        $selectProduto = "SELECT CDFILIAL, CDPRODUTO  FROM LIMISEGPROD WHERE (CDFILIAL = :P_CDFILIAL) AND (CDPRODUTO = :P_CDPRODUTO) ";
        
        $params                = array();
        $params['P_CDFILIAL']  = $data[0]['CDFILIAL'];
        $params['P_CDPRODUTO'] = $data[0]['CDPRODUTO'];
        
        
        $stmt = $this->connection->prepare($selectProduto);
        $stmt->execute($params);
        $retorno = $stmt->fetchAll();
        $response->addDataSet(new DataSet("resp", $retorno));
        
        
    }
    
    public function popUpLimSeg(DTO\Request $request, DTO\Response $response){
        
        $data = $request->getRow();
        $select = "SELECT PERFILPROD.CDFILIAL, PERFILPROD.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PERFILPROD.CDPERIENTR, PERIENTR.NMPERIENTR, PERFILPROD.IDDNULIMSEGPR, PERFILPROD.IDSITUENTREGA, PERFILPROD.NRORG FROM PERFILPROD, PRODUTO, PERIENTR WHERE (PERFILPROD.CDFILIAL = :P_CDFILIAL) AND (PERFILPROD.CDPRODUTO = :P_CDPRODUTO) AND (PERIENTR.CDPERIENTR = :P_CDPERIENTR) AND (PERFILPROD.NRORG = :P_NRORG) AND (PRODUTO.CDPRODUTO = PERFILPROD.CDPRODUTO) AND (PERIENTR.CDPERIENTR = PERFILPROD.CDPERIENTR) ORDER BY PRODUTO.CDARVPROD";
        
        $params                = array();
        $params['P_CDFILIAL']  = $data['P_CDFILIAL'];
        $params['P_CDPRODUTO'] = $data['P_CDPRODUTO'];
        $params['P_CDPERIENTR']  = $data['P_CDPERIENTR'];
        $params['P_NRORG'] = $data['P_NRORG'];
        
        $stmt = $this->connection->prepare($select);
        $stmt->execute($params);
        $retorno = $stmt->fetchAll();
        $response->addDataSet(new DataSet("resp", $retorno));
        
        
    }
    
    public function verificaEstoqueSeguranca(DTO\Request $request, DTO\Response $response){
        
        $data = $request->getDataSet()->getRows();
        
        $selectProduto = "SELECT CDFILIAL, CDPRODESTO  FROM ESTOSEGU WHERE (CDFILIAL = :P_CDFILIAL) AND (CDPRODESTO = :P_CDPRODUTO) ";
        
        $params                = array();
        $params['P_CDFILIAL']  = $data[0]['CDFILIAL'];
        $params['P_CDPRODUTO'] = $data[0]['CDPRODUTO'];
        
        
        $stmt = $this->connection->prepare($selectProduto);
        $stmt->execute($params);
        $retorno = $stmt->fetchAll();
        $response->addDataSet(new DataSet("resp", $retorno));
        
        
    }
     public function verificaFilial(DTO\Request $request, DTO\Response $response){
        
        $data = $request->getDataSet()->getRows();
        
        $select = "SELECT CDFILIAL FROM FILIAL WHERE IDFUNCAOFILI = 'O' AND CDFILIAL = :P_CDFILIAL";
        
        $params                = array();
        $params['P_CDFILIAL']  = $data[0]['CDFILIAL'];
        
        
        $stmt = $this->connection->prepare($select);
        $stmt->execute($params);
        $retorno = $stmt->fetchAll();
        $response->addDataSet(new DataSet("resp", $retorno));
        
        
    }
     public function insereLimiteSeguranca(DTO\Request $request, DTO\Response $response)
    {
         $data = $request->getDataSet()->getRows();
         $params              = array();
                $params['CDFILIAL']  = $data[0]['CDFILIAL'];
                $params['CDPRODUTO'] = $data[0]['CDPRODUTO'];
                $params['NRLIMISEGU'] = $data[0]['NRLIMISEGU'];
                $params['NRORG']     = $this->environment->getNrorg();
                
        
        $sql = "INSERT INTO LIMISEGPROD (CDFILIAL, CDPRODUTO, NRLIMISEGU, NRORG) VALUES (:CDFILIAL, :CDPRODUTO, :NRLIMISEGU, :NRORG)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
                
        
    }
     public function editaLimiteSeguranca(DTO\Request $request, DTO\Response $response)
    {
        
         $data = $request->getDataSet()->getRows();
         $params              = array();
                $params['CDFILIAL']  = $data[0]['CDFILIAL'];
                $params['CDPRODUTO'] = $data[0]['CDPRODUTO'];
                $params['NRLIMISEGU'] = $data[0]['NRLIMISEGU'];
                $params['OLD_CDFILIAL'] = $data[0]['CDFILIAL'];
                $params['OLD_CDPRODUTO'] = $data[0]['CDPRODUTO'];
                $params['NRORG']     = $this->environment->getNrorg();
                
        
        
        $sql = "UPDATE LIMISEGPROD SET CDFILIAL = :CDFILIAL, CDPRODUTO = :CDPRODUTO, NRLIMISEGU = :NRLIMISEGU WHERE CDFILIAL = :OLD_CDFILIAL AND CDPRODUTO = :OLD_CDPRODUTO AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
                
        
    }
    public function deleteLimiteSeguranca(DTO\Request $request, DTO\Response $response)
     {
        $data = $request->getRow();
        
        $query = 'DELETE FROM LIMISEGPROD WHERE CDFILIAL = :OLD_CDFILIAL AND CDPRODUTO = :OLD_CDPRODUTO AND NRORG = :NRORG';
        $stmt  = $this->connection->prepare($query);
        $stmt->execute(array(
            "OLD_CDFILIAL" => $data['CDFILIAL'],
            "OLD_CDPRODUTO" => $data['CDPRODUTO'],
            "NRORG" =>  $this->environment->getNrorg()
        ));
    }
     public function insereEstoqueSeguranca(DTO\Request $request, DTO\Response $response)
    {
         $data = $request->getDataSet()->getRows();
         $params              = array();
                $params['CDFILIAL']  = $data[0]['CDFILIAL'];
                $params['CDPRODESTO'] = $data[0]['CDPRODUTO'];
                $params['QTESTOSEGU'] = $data[0]['QTESTOSEGU'];
                $params['NRDIACALCESTSEGOL'] = $data[0]['NRDIACALCESTSEGOL'];
                $params['NRORG']     = $this->environment->getNrorg();
                
        
        $sql = "INSERT INTO ESTOSEGU (CDFILIAL, CDPRODESTO, QTESTOSEGU, NRDIACALCESTSEGOL, NRORG) VALUES (:CDFILIAL, :CDPRODESTO, :QTESTOSEGU, :NRDIACALCESTSEGOL, :NRORG)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
                
        
    }
     public function editaEstoqueSeguranca(DTO\Request $request, DTO\Response $response)
    {
         $data = $request->getDataSet()->getRows();
         $params              = array();
                $params['CDFILIAL']  = $data[0]['CDFILIAL'];
                $params['CDPRODESTO'] = $data[0]['CDPRODESTO'];
                $params['QTESTOSEGU'] = $data[0]['QTESTOSEGU'];
                $params['NRDIACALCESTSEGOL'] = $data[0]['NRDIACALCESTSEGOL'];
                $params['OLD_CDFILIAL'] = $data[0]['CDFILIAL'];
                $params['OLD_CDPRODESTO'] = $data[0]['CDPRODESTO'];
                $params['NRORG']     = $this->environment->getNrorg();
                
        
        $sql = "UPDATE ESTOSEGU SET CDFILIAL = :CDFILIAL, CDPRODESTO = :CDPRODESTO, QTESTOSEGU = :QTESTOSEGU, NRDIACALCESTSEGOL = :NRDIACALCESTSEGOL WHERE CDFILIAL = :OLD_CDFILIAL AND CDPRODESTO = :OLD_CDPRODESTO AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
                
        
    }
    public function deleteEstoqueSeguranca(DTO\Request $request, DTO\Response $response)
     {
        $data = $request->getRow();
        
        $query = 'DELETE FROM ESTOSEGU WHERE CDFILIAL = :OLD_CDFILIAL AND CDPRODESTO = :OLD_CDPRODESTO AND NRORG = :NRORG';
        $stmt  = $this->connection->prepare($query);
        $stmt->execute(array(
            "OLD_CDFILIAL" => $data['CDFILIAL'],
            "OLD_CDPRODESTO" => $data['CDPRODESTO'],
            "NRORG" =>  $this->environment->getNrorg()
        ));
    }
    
    public function updateCustoLista(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        foreach ($row['LISTAS'] as $lista) {
            $para  = array(
                'CDFILCUS'   => $row['CDFILCUS'],
                'CDOPERADOR' => $row['CDOPERADOR']
            );
            $this->updateLogAtuCusto($lista, $para);
            $this->callProcedureListaCusto($lista, $para);
            /*if (boLimpaTemp){
                $this->chamaQuery1();
                $this->chamaQuery2();
            }*/
            $this->updateAtuCusto($lista, $para);
        }
    }
    
    public function updateLogAtuCusto(array $lista, array $para){
        $query = 'INSERT INTO LOGCUSTLISTA(CDCENTCMPLAC, NRLISTPRELAC, CDTELAATULAC, CDOPERATULAC, CDFILIATULAC, DTINICUSLAC) VALUES (:CDCENTCMPLAC, :NRLISTPRELAC, \'CMP02500\', :CDOPERATULAC, :CDFILIATULAC, SYSDATE)';
        
        $params = array();
        $params['CDCENTCMPLAC'] = $lista['CDFILIAL'];
        $params['NRLISTPRELAC'] = $lista['NRSEQPRELIST'];
        $params['CDOPERATULAC'] = $para['CDOPERADOR'];
        $params['CDFILIATULAC'] = $para['CDFILCUS'];

        $std = $this->connection->prepare($query);
        $std->execute($params);
    }
    
    public function callProcedureListaCusto(array $lista, array $para){
        try{
            $procedure = new StoredProcedure($this->connection, 'LISPREC_UPPRODFILI');
            
            $procedure->addParam(new Param('P_CDFILIAL',     Param::PARAM_INPUT,  $lista['CDFILIAL'],     Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRSEQPRELIST', Param::PARAM_INPUT,  $lista['NRSEQPRELIST'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_ATUCUSTO',     Param::PARAM_INPUT,  $lista['IDATUCUSLIST'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDFILCUSTO',   Param::PARAM_INPUT,  $para['CDFILCUS'],      Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDLISTAREG',   Param::PARAM_INPUT,  NULL,                   Param::PARAM_TYPE_STR));
            
            $procedure->execute();
            
        }catch(\Exception $e){
            return $e;
        }
    }
    
    /*public function deleteCustoSupTMP(){
        $query = 'DELETE CUSTOSUP_TMP WHERE CDFILCENTCMP = :P_CDFILIAL AND NRSEQPRELIST = :P_NRSEQPRELIST';
      
        $params = array();
        $params['P_CDFILIAL'] = $lista['CDFILIAL'];
        $params['P_NRSEQPRELIST'] = $lista['NRSEQPRELIST'];
        
        $std = $this->connection->prepare($query);
        $std->execute($params);
    }*/
    
    /*public function deleteCustoSupAcorTMP(){
        $query = 'DELETE CUSTOSUPACOR_TMP WHERE CDFILCENTCMP = :P_CDFILIAL AND NRSEQPRELIST = :P_NRSEQPRELIST';
      
        $params = array();
        $params['P_CDFILIAL'] = $lista['CDFILIAL'];
        $params['P_NRSEQPRELIST'] = $lista['NRSEQPRELIST'];
        
        $std = $this->connection->prepare($query);
        $std->execute($params);
    }*/
    
    public function updateAtuCusto(array $lista, array $para){
        $query = 'UPDATE LOGCUSTLISTA SET DTATUACUSLAC = SYSDATE WHERE CDCENTCMPLAC = :CDCENTCMPLAC AND NRLISTPRELAC = :NRLISTPRELAC AND CDTELAATULAC = \'CMP02500\' AND CDOPERATULAC = :CDOPERATULAC AND CDFILIATULAC = :CDFILIATULAC AND DTINICUSLAC =(SELECT MAX(DTINICUSLAC) FROM LOGCUSTLISTA L WHERE L.CDCENTCMPLAC = :CDCENTCMPLAC AND L.NRLISTPRELAC = :NRLISTPRELAC AND L.CDTELAATULAC = \'CMP02500\' AND L.CDOPERATULAC = :CDOPERATULAC AND L.CDFILIATULAC = :CDFILIATULAC)';
      
        $params = array();
        $params['CDCENTCMPLAC'] = $lista['CDFILIAL'];
        $params['NRLISTPRELAC'] = $lista['NRSEQPRELIST'];
        $params['CDOPERATULAC'] = $para['CDOPERADOR'];
        $params['CDFILIATULAC'] = $para['CDFILCUS'];
        
        $std = $this->connection->prepare($query);
        $std->execute($params);
    }
    
    private function strPadRigthProd($value){
        return str_pad($value, 20, 'Z', STR_PAD_RIGHT);
    }
    
    public function exportar(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $paramsGeraisExportar = array (
            "P_CDFILDEST" => $row['CDFILDEST'],    
            "P_CDFILORIG" => $row['CDFILORIG'],    
            "P_CDPRODINI" => $row['CDPRODINI'],    
            "P_CDPRODFIN" => $row['CDPRODFIN'] = self::strPadRigthProd($row['CDPRODFIN'])    
        );
        switch ($row['TIPOEXPORTAR']) {
            case 'CMP02500':
                $this->exportarProdutoComprado($row, $paramsGeraisExportar);
                break;
            
            case 'CMP02502':
                $this->exportarPeriodicidadeEntrega($row);
                break;
            
            case 'CMP02503':
                $this->exportarDestinatarioAF($row, $paramsGeraisExportar);
                break;
            
            default:
                $this->exportarLimiteSeguranca($row, $paramsGeraisExportar);
        }
    }
    
    public function exportarProdutoComprado(DTO\Row $row, array $params){
        $this->exportarProdutoCompradoDelete($row, $params);
        $this->exportarProdutoCompradoInsert($row, $params);
    }
    public function exportarProdutoCompradoDelete(DTO\Row $row, array $params){
        $query = "DELETE FROM PRODCMPFILI WHERE CDFILIAL IN(SELECT CDFILIAL FROM FILIAL WHERE (INSTR(:P_CDFILDEST,CDFILIAL) <> 0 OR :P_CDFILDEST = 'T') AND CDFILIAL <> :P_CDFILORIG) AND CDPRODUTO IN (SELECT CDPRODUTO FROM PRODUTO WHERE CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN)";
        self::executaSql($query, $params, false);
    }
    public function exportarProdutoCompradoInsert(DTO\Row $row, array $params){
        $query = "INSERT INTO PRODCMPFILI(CDFILIAL, CDPRODUTO) (SELECT A.CDFILIAL, B.CDPRODUTO FROM (SELECT CDFILIAL FROM FILIAL WHERE (INSTR(:P_CDFILDEST,CDFILIAL) <> 0 OR :P_CDFILDEST = 'T') AND (CDFILIAL <> :P_CDFILORIG)) A, PRODCMPFILI B, PRODUTO WHERE (B.CDFILIAL = :P_CDFILORIG) AND (B.CDPRODUTO = PRODUTO.CDPRODUTO) AND ((PRODUTO.CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN) OR (PRODUTO.CDARVPROD BETWEEN :P_CDPRODFIN AND :P_CDPRODINI)) AND NOT EXISTS(SELECT '1' FROM PRODNCMP WHERE INSTR(:P_CDFILDEST, CDFILIAL) <> 0 AND PRODNCMP.CDPRODUTO = B.CDPRODUTO))";
        self::executaSql($query, $params, false);
    }
    
    
    public function exportarPeriodicidadeEntrega(DTO\Row $row){
       
        
        
        $params = array (
            "P_CDFILDEST"  => $row['CDFILDEST'],    
            "P_CDFILORIG"  => $row['CDFILORIG'],    
            "P_CDGRUPFILI" => $row['CDGRUPFILI'],    
            "P_CDPRODINI"  => $row['CDPRODINI'],    
            "P_CDPRODFIN"  => $row['CDPRODFIN'] = self::strPadRigthProd($row['CDPRODFIN'])    
        );
        
        $this->exportarPeriodicidadeEntregaDelete($row, $params);
        $this->exportarPeriodicidadeEntregaInsert($row, $params);
    }
    public function exportarPeriodicidadeEntregaDelete(DTO\Row $row, array $params){
        $query = "DELETE FROM PERFILPROD WHERE CDFILIAL IN(SELECT CDFILIAL FROM FILIAL WHERE (INSTR(:P_CDFILDEST,CDFILIAL) <> 0 OR :P_CDFILDEST = 'T') AND (CDFILIAL <> :P_CDFILORIG) AND (:P_CDGRUPFILI = 'T' OR EXISTS(SELECT :P_CDGRUPFILI FROM FILGRUPFILI WHERE FILGRUPFILI.CDFILIAL = FILIAL.CDFILIAL AND FILGRUPFILI.CDGRUPFILI = :P_CDGRUPFILI) ) ) AND CDPRODUTO IN (SELECT CDPRODUTO FROM PRODUTO WHERE CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN)";
        self::executaSql($query, $params, false);
    }
    public function exportarPeriodicidadeEntregaInsert(DTO\Row $row, array $params){
        $query = "INSERT INTO PERFILPROD(CDFILIAL, CDPRODUTO, CDPERIENTR) (SELECT A.CDFILIAL, B.CDPRODUTO, B.CDPERIENTR FROM (SELECT CDFILIAL FROM FILIAL WHERE (INSTR(:P_CDFILDEST,CDFILIAL) <> 0 OR :P_CDFILDEST = 'T') AND (CDFILIAL <> :P_CDFILORIG) AND (:P_CDGRUPFILI = 'T' OR EXISTS(SELECT :P_CDGRUPFILI FROM FILGRUPFILI WHERE FILGRUPFILI.CDGRUPFILI = :P_CDGRUPFILI AND FILGRUPFILI.CDFILIAL = FILIAL.CDFILIAL)) ) A, PERFILPROD B, PRODUTO WHERE (B.CDFILIAL = :P_CDFILORIG) AND (B.CDPRODUTO = PRODUTO.CDPRODUTO) AND (PRODUTO.CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN))";
        self::executaSql($query, $params, false);
    }
    
    
    public function exportarDestinatarioAF(DTO\Row $row, array $params){
        $this->exportarDestinatarioAFDelete($row, $params);
        $this->exportarDestinatarioAFInsert($row, $params);
    }
    public function exportarDestinatarioAFDelete(DTO\Row $row, array $params){
        $query = "DELETE FROM EMITENTEAF WHERE CDFILIAL IN(SELECT CDFILIAL FROM FILIAL WHERE (INSTR(:P_CDFILDEST,CDFILIAL) <> 0 OR :P_CDFILDEST = 'T') AND (CDFILIAL <> :P_CDFILORIG)) AND CDPRODUTO IN (SELECT CDPRODUTO FROM PRODUTO WHERE CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN)";
        self::executaSql($query, $params, false);
    }
    public function exportarDestinatarioAFInsert(DTO\Row $row, array $params){
        $query = "INSERT INTO EMITENTEAF(CDFILIAL, CDPRODUTO, CDEMPRESA, IDEMITAFDES) (SELECT A.CDFILIAL, B.CDPRODUTO, B.CDEMPRESA, B.IDEMITAFDES FROM (SELECT CDFILIAL FROM FILIAL WHERE (INSTR(:P_CDFILDEST,CDFILIAL) <> 0 OR :P_CDFILDEST = 'T') AND (CDFILIAL <> :P_CDFILORIG)) A, EMITENTEAF B, PRODUTO WHERE (B.CDFILIAL = :P_CDFILORIG) AND (B.CDPRODUTO = PRODUTO.CDPRODUTO) AND (PRODUTO.CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN))";
        self::executaSql($query, $params, false);
    }
    
    
    public function exportarLimiteSeguranca(DTO\Row $row, array $params){
        $this->exportarLimiteSegurancaDelete($row, $params);
        $this->exportarLimiteSegurancaInsert($row, $params);
    }
    public function exportarLimiteSegurancaDelete(DTO\Row $row, array $params){
        $query = "DELETE FROM LIMISEGPROD WHERE CDFILIAL IN(SELECT CDFILIAL FROM FILIAL WHERE (INSTR(:P_CDFILDEST,CDFILIAL) <> 0 OR :P_CDFILDEST = 'T') AND (CDFILIAL <> :P_CDFILORIG)) AND CDPRODUTO IN (SELECT CDPRODUTO FROM PRODUTO WHERE CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN)";
        self::executaSql($query, $params, false);
    }
    public function exportarLimiteSegurancaInsert(DTO\Row $row, array $params){
        $query = "INSERT INTO LIMISEGPROD(CDFILIAL, CDPRODUTO, NRLIMISEGU) (SELECT A.CDFILIAL, B.CDPRODUTO, B.NRLIMISEGU FROM (SELECT CDFILIAL FROM FILIAL WHERE (INSTR(:P_CDFILDEST,CDFILIAL) <> 0 OR :P_CDFILDEST = 'T') AND (CDFILIAL <> :P_CDFILORIG)) A, LIMISEGPROD B, PRODUTO WHERE (B.CDFILIAL = :P_CDFILORIG) AND (B.CDPRODUTO = PRODUTO.CDPRODUTO) AND (PRODUTO.CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN))";
        self::executaSql($query, $params, false);
    }

    
    protected $reportMapping = array ();
    
     public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
        $this->stNomeRel = $this->getReportName($row);
        $this->reportMapping[$this->stNomeRel] =
            array (
                'strategy' => $row['STRATEGY'],
                'parameterMapping' =>
                    array (
                        "CDPRODINI"  => "P_CDPRODINI",   
                        "CDPRODFIN"  => "P_CDPRODFINSTR",
                        "NMPRODINI"  => "P_NMPRODINI",   
                        "NMPRODFIN"  => "P_NMPRODFIN",   
                        "CDGRUPFILI" => "P_CDGRUPFILI",
                        "CDPRODFINZ" => "P_CDPRODFIN",   
                        "CDFILIAL"   => "L_FILIAL"
                    )
                );
    }
}
 
