<?php

namespace Modules\Cadastros\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Util\SupUtilities;

class FilialAtendidaNaoAtendidaPeloFornecedorService {
    
    
    public function __construct(SupUtilities $supUtilities){
        $this->supUtilities      = $supUtilities;
    }
    
    /********************
     *      INSERTS     *
     * ******************/
    
    public function insertCodPeri($row){    
        try {
            $query = "INSERT INTO REFORFIL (CDFORNECED, CDFILIAL, CDPERIENTR, NRORG) VALUES (:CDFORNECED, :CDFILIAL, :CDPERIENTR, :NRORG)";
            $param = [
                'CDFORNECED' => $row['CDFORNECED'],
                'CDFILIAL'   => $row['CDFILIAL'],
                'CDPERIENTR' => $row['CDPERIENTR'],
                'NRORG'      => $row['NRORG']
            ];
            return $this->supUtilities->crud($query, $param);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir período!');
        }
    }
    
    public function insertFilial($row){    
        try {
            $query = "INSERT INTO REFORFIL (CDFORNECED, CDFILIAL, NRORG) VALUES (:CDFORNECED, :CDFILIAL, :NRORG)";
            $params = [
                'CDFORNECED' => $row['CDFORNECED'],
                'CDFILIAL'   => $row['CDFILIAL'],
                'NRORG'      => $row['NRORG']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir unidade!');
        }
    }
    
    public function insertExportation($row){    
        try {
            $query = "INSERT INTO REFORFIL ( CDFORNECED, CDFILIAL, NRORG ) SELECT FORNECEDOR.CDFORNECED, REFORFIL.CDFILIAL, FORNECEDOR.NRORG FROM REFORFIL, FORNECEDOR WHERE REFORFIL.CDFORNECED =:P_CDFORNORG AND ( INSTR(:P_CDFORNDES,FORNECEDOR.CDFORNECED) <> 0 OR :P_CDFORNDES = 'T' ) AND ( INSTR(:P_CDFIL,REFORFIL.CDFILIAL) <> 0 OR :P_CDFIL = 'T' ) AND ( REFORFIL.CDPERIENTR IS NULL ) AND (FORNECEDOR.NRORG = REFORFIL.NRORG) AND NOT EXISTS ( SELECT A.CDFILIAL FROM REFORFIL A WHERE A.CDFILIAL = REFORFIL.CDFILIAL AND A.CDFORNECED = FORNECEDOR.CDFORNECED )";
            $params = [
                'P_CDFORNORG' => $row['CDFORNECEDORIG'],
                'P_CDFORNDES' => $row['CDFORNECEDDEST'],
                'P_CDFIL'     => $row['CDFILIAL']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir unidade!');
        }
    }
    
    public function insertPrazo($row){    
        try {
            $query = "INSERT INTO PRAZOFORNEXPEDFIL (NRPRAZOFORNEXPEDFIL, CDFORNECED, CDFILIAL, QTDIASPRAZOEXPED) VALUES (:NRPRAZOFORNEXPEDFIL, :CDFORNECED, :CDFILIAL, :QTDIASPRAZOEXPED)";
            $params = [
                'NRPRAZOFORNEXPEDFIL'   => $row['NRPRAZOFORNEXPEDFIL'],
                'CDFORNECED'            => $row['CDFORNECED'],
                'CDFILIAL'              => $row['CDFILIAL'],
                'QTDIASPRAZOEXPED'      => $row['QTDIASPRAZOEXPED']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir Prazo!');
        }
    }
    
    
    /********************
     *      UPDATES     *
     * ******************/
     
     
    public function updateCodPeri($row) {
        try {
            $query = "UPDATE REFORFIL SET CDFORNECED = :CDFORNECED, CDFILIAL = :CDFILIAL, CDPERIENTR = :CDPERIENTR WHERE CDFORNECED = :OLD_CDFORNECED AND CDFILIAL = :OLD_CDFILIAL";
            $params = [
                'CDFORNECED'     => $row['CDFORNECED'],
                'CDFILIAL'       => $row['CDFILIAL'],
                'CDPERIENTR'     => $row['CDPERIENTR'],
                'OLD_CDFORNECED' => $row['CDFORNECED'],
                'OLD_CDFILIAL'   => $row['CDFILIAL']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao atualizar período!');
        }
    }
    public function updatePrazo($row) {
        try {
            $query ="UPDATE PRAZOFORNEXPEDFIL  SET QTDIASPRAZOEXPED = :QTDIASPRAZOEXPED  WHERE NRPRAZOFORNEXPEDFIL = :NRPRAZOFORNEXPEDFIL";
            $params = [
                'QTDIASPRAZOEXPED'     => $row['QTDIASPRAZOEXPED'],
                'NRPRAZOFORNEXPEDFIL'  => $row['NRPRAZOFORNEXPEDFIL']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao atualizar Prazo!');
        }
    }
    
    /********************
     *      DELETES     *
     * ******************/
     
    
    public function deleteFilial($row) {
        try {
            $query = "DELETE FROM REFORFIL WHERE CDFORNECED = :OLD_CDFORNECED AND CDFILIAL = :OLD_CDFILIAL";
            $params = [
                'OLD_CDFORNECED' => $row['CDFORNECED'],
                'OLD_CDFILIAL'   => $row['CDFILIAL']
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao deletar unidade!');
        }
    }
    public function deletePrazo($row) {
        try {
            $query = "DELETE FROM PRAZOFORNEXPEDFIL WHERE NRPRAZOFORNEXPEDFIL = :NRPRAZOFORNEXPEDFIL";
            $params = [
                'NRPRAZOFORNEXPEDFIL' => $row['NRPRAZOFORNEXPEDFIL'],
            ];
            $this->supUtilities->crud($query, $params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao deletar Prazo!');
        }
    }
    
    /********************
     *      SELECTS     *
     * ******************/
     
     
    public function findCodPeri($row) {
        $query = 'SELECT FILIAL.CDFILIAL, FILIAL.NMFILIAL, PERIENTR.CDPERIENTR, PERIENTR.NMPERIENTR, PERIENTR.CDFORNECED, FILIAL.NRORG FROM FILIAL, ENDEFILI, ( SELECT REFORFIL.CDFILIAL, REFORFIL.CDPERIENTR, PERIENTR.NMPERIENTR, REFORFIL.CDFORNECED, REFORFIL.NRORG FROM REFORFIL, PERIENTR WHERE REFORFIL.CDFORNECED =:P_CDFORNECED AND REFORFIL.CDPERIENTR = PERIENTR.CDPERIENTR ) PERIENTR WHERE ( FILIAL.CDFILIAL = ENDEFILI.CDFILIAL ) AND ( FILIAL.CDFILIAL = PERIENTR.CDFILIAL (+) ) AND (FILIAL.CDFILIAL = :P_CDFILIAL) AND ( ENDEFILI.IDTPENDEFILI =:P ) AND ( ENDEFILI.CDPAIS =:P_CDPAIS ) AND ( ENDEFILI.SGESTADO =:P_SGESTADO ) AND ( ENDEFILI.CDMUNICIPIO =:P_CDMUNICIPIO ) AND NOT EXISTS ( SELECT RF.CDFORNECED FROM REFORFIL RF WHERE RF.CDFORNECED =:P_CDFORNECED AND RF.CDFILIAL = FILIAL.CDFILIAL AND RF.CDPERIENTR IS NULL ) ORDER BY FILIAL.CDFILIAL';
        $params = [
            'P_SGESTADO'    => $row['SGESTADO'],
            'P_CDMUNICIPIO' => $row['CDMUNICIPIO'],
            'P_CDPAIS'      => $row['CDPAIS'],
            'P_CDFORNECED'  => $row['CDFORNECED'],
            'P_CDFILIAL'    => $row['CDFILIAL'],
            'P'             => 'P'
        ];
        return $this->supUtilities->crud($query, $params)[0];
    }
    
    public function findFilial($row) {
        $query = 'SELECT REFORFIL.CDFORNECED, REFORFIL.CDFILIAL, REFORFIL.NRORG, FILIAL.NMFILIAL FROM REFORFIL, FILIAL WHERE ( REFORFIL.CDFORNECED =:P_CDFORNECED ) AND ( REFORFIL.CDFILIAL = FILIAL.CDFILIAL ) AND ( REFORFIL.NRORG = FILIAL.NRORG ) AND ( CDPERIENTR IS NULL ) ORDER BY REFORFIL.CDFILIAL';
        $params = ['P_CDFORNECED'  => $row['CDFORNECED']];
        return  $this->supUtilities->crud($query, $params);
    }
    
    public function findFilialRegiaoNaoAtendida($row){
        $query = "SELECT REFOREG.CDFORNECED, REFOREG.CDREGIAO, REGIAO.NMREGIAO FROM REFOREG, REGIAO WHERE(REFOREG.CDFORNECED = :P_CDFORNECED) AND (REFOREG.CDREGIAO = REGIAO.CDREGIAO) AND (REGIAO.CDREGIAO IN (select cdregiao from filial where cdfilial = :cdfilial)) ORDER BY REFOREG.CDREGIAO";
        $params = [
            ':P_CDFORNECED'  => $row[0]['CDFORNECED'],
            ':cdfilial'      => $row[0]['CDFILIAL']
        ];
        return  $this->supUtilities->crud($query, $params);
    }
      public function verificaPrazo($row){
        $query = "SELECT NVL(MAX('S'), 'N') AS PERMITE  FROM FORNECEDOR, FILIAL, PARAMGERAL WHERE FILIAL.CDFILIAL     = :CDFILIAL    AND FILIAL.CDFORNOPELOG = FORNECEDOR.CDFORNECED     AND FILIAL.IDFUNCAOFILI = 'O'   AND PARAMGERAL.IDSISDOS = '3'";
        $params = [
            'CDFILIAL'      => $row['CDFILIAL']
        ];
        return  $this->supUtilities->crud($query, $params);
    }
      public function retornaProxprazo($row){
        $query = "SELECT SEQ_PRAZOFORNEXPEDFIL.NEXTVAL AS PROXPRAZO  FROM DUAL";
        return  $this->supUtilities->crud($query);
      }
    }